@@ -1,6 +1,15 @@
-getgrstplot <-
-function (rlme.fit) 
-{
+#' Q-Q Plot and Standardized Residual Plot for the GR fit.
+#' 
+#' It gets Q-Q Plot and Standardized Residual Plot of residuals.
+#' 
+#' The fit is obtained from rlme()
+#' 
+#' 
+#' @param rlme.fit RLME fit object
+#' @seealso rlme 
+#' 
+#' @export
+getgrstplot <- function(rlme.fit) {
     y = rlme.fit$y
     xstar = rlme.fit$xstar
     ystar = rlme.fit$ystar
@@ -21,9 +30,21 @@ function (rlme.fit)
     list(sresid=standr.gr)
 }
 
-getlmestplot <-
-function (rlme.fit) 
-{
+
+
+#' Q-Q Plot and Standardized Residual Plot for the REML or ML fit.
+#' 
+#' It gets Q-Q Plot and Standardized Residual Plot of residuals.
+#' concise (1-5 lines) description of what the function does.
+#' 
+#' 
+#' @param rlme.fit The fit is obtained from rlme()
+#' 
+#' @seealso rlme 
+#' 
+#' @export
+#' 
+getlmestplot <- function(rlme.fit) {
     standr.lme = rlme.fit$standr.lme
     y = rlme.fit$y
     yhat.lme = y - rlme.fit$effect.err
@@ -36,4 +57,4 @@ function (rlme.fit)
     qqline(standr.lme, col = "red")
     par(mfrow = c(1, 1))
     list(sresid=standr.lme)
-}
+}
\ No newline at end of file
