@@ -1,6 +1,4 @@
-jmake <-
-function (n) 
-{
+jmake <- function(n) {
     jmake = matrix(rep(1, n^2), ncol = n)
     jmake
 }
