@@ -1,6 +1,4 @@
-projcsp <-
-function (xstar, yhat) 
-{
+projcsp <- function(xstar, yhat) {
     theta = solve(t(xstar) %*% xstar) %*% t(xstar) %*% yhat
     new = xstar %*% theta
     list(betahat = theta, yhat = new)
